==> apigateway-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/CfnRouteResponseV2Props.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Properties for defining a `AWS::ApiGatewayV2::RouteResponse`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:27:21.904Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnRouteResponseV2Props extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ApiGatewayV2::RouteResponse.ApiId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html#cfn-apigatewayv2-routeresponse-apiid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getApiId();

    /**
     * `AWS::ApiGatewayV2::RouteResponse.RouteId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html#cfn-apigatewayv2-routeresponse-routeid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getRouteId();

    /**
     * `AWS::ApiGatewayV2::RouteResponse.RouteResponseKey`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html#cfn-apigatewayv2-routeresponse-routeresponsekey
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getRouteResponseKey();

    /**
     * `AWS::ApiGatewayV2::RouteResponse.ModelSelectionExpression`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html#cfn-apigatewayv2-routeresponse-modelselectionexpression
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getModelSelectionExpression();

    /**
     * `AWS::ApiGatewayV2::RouteResponse.ResponseModels`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html#cfn-apigatewayv2-routeresponse-responsemodels
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getResponseModels();

    /**
     * `AWS::ApiGatewayV2::RouteResponse.ResponseParameters`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html#cfn-apigatewayv2-routeresponse-responseparameters
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getResponseParameters();

    /**
     * @return a {@link Builder} of {@link CfnRouteResponseV2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnRouteResponseV2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.String apiId;
        private java.lang.String routeId;
        private java.lang.String routeResponseKey;
        private java.lang.String modelSelectionExpression;
        private java.lang.Object responseModels;
        private java.lang.Object responseParameters;

        /**
         * Sets the value of ApiId
         * @param apiId `AWS::ApiGatewayV2::RouteResponse.ApiId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder apiId(java.lang.String apiId) {
            this.apiId = apiId;
            return this;
        }

        /**
         * Sets the value of RouteId
         * @param routeId `AWS::ApiGatewayV2::RouteResponse.RouteId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder routeId(java.lang.String routeId) {
            this.routeId = routeId;
            return this;
        }

        /**
         * Sets the value of RouteResponseKey
         * @param routeResponseKey `AWS::ApiGatewayV2::RouteResponse.RouteResponseKey`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder routeResponseKey(java.lang.String routeResponseKey) {
            this.routeResponseKey = routeResponseKey;
            return this;
        }

        /**
         * Sets the value of ModelSelectionExpression
         * @param modelSelectionExpression `AWS::ApiGatewayV2::RouteResponse.ModelSelectionExpression`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder modelSelectionExpression(java.lang.String modelSelectionExpression) {
            this.modelSelectionExpression = modelSelectionExpression;
            return this;
        }

        /**
         * Sets the value of ResponseModels
         * @param responseModels `AWS::ApiGatewayV2::RouteResponse.ResponseModels`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder responseModels(java.lang.Object responseModels) {
            this.responseModels = responseModels;
            return this;
        }

        /**
         * Sets the value of ResponseParameters
         * @param responseParameters `AWS::ApiGatewayV2::RouteResponse.ResponseParameters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder responseParameters(java.lang.Object responseParameters) {
            this.responseParameters = responseParameters;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnRouteResponseV2Props}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnRouteResponseV2Props build() {
            return new Jsii$Proxy(apiId, routeId, routeResponseKey, modelSelectionExpression, responseModels, responseParameters);
        }
    }

    /**
     * An implementation for {@link CfnRouteResponseV2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnRouteResponseV2Props {
        private final java.lang.String apiId;
        private final java.lang.String routeId;
        private final java.lang.String routeResponseKey;
        private final java.lang.String modelSelectionExpression;
        private final java.lang.Object responseModels;
        private final java.lang.Object responseParameters;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.apiId = this.jsiiGet("apiId", java.lang.String.class);
            this.routeId = this.jsiiGet("routeId", java.lang.String.class);
            this.routeResponseKey = this.jsiiGet("routeResponseKey", java.lang.String.class);
            this.modelSelectionExpression = this.jsiiGet("modelSelectionExpression", java.lang.String.class);
            this.responseModels = this.jsiiGet("responseModels", java.lang.Object.class);
            this.responseParameters = this.jsiiGet("responseParameters", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String apiId, java.lang.String routeId, java.lang.String routeResponseKey, java.lang.String modelSelectionExpression, java.lang.Object responseModels, java.lang.Object responseParameters) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.apiId = java.util.Objects.requireNonNull(apiId, "apiId is required");
            this.routeId = java.util.Objects.requireNonNull(routeId, "routeId is required");
            this.routeResponseKey = java.util.Objects.requireNonNull(routeResponseKey, "routeResponseKey is required");
            this.modelSelectionExpression = modelSelectionExpression;
            this.responseModels = responseModels;
            this.responseParameters = responseParameters;
        }

        @Override
        public java.lang.String getApiId() {
            return this.apiId;
        }

        @Override
        public java.lang.String getRouteId() {
            return this.routeId;
        }

        @Override
        public java.lang.String getRouteResponseKey() {
            return this.routeResponseKey;
        }

        @Override
        public java.lang.String getModelSelectionExpression() {
            return this.modelSelectionExpression;
        }

        @Override
        public java.lang.Object getResponseModels() {
            return this.responseModels;
        }

        @Override
        public java.lang.Object getResponseParameters() {
            return this.responseParameters;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("apiId", om.valueToTree(this.getApiId()));
            obj.set("routeId", om.valueToTree(this.getRouteId()));
            obj.set("routeResponseKey", om.valueToTree(this.getRouteResponseKey()));
            if (this.getModelSelectionExpression() != null) {
                obj.set("modelSelectionExpression", om.valueToTree(this.getModelSelectionExpression()));
            }
            if (this.getResponseModels() != null) {
                obj.set("responseModels", om.valueToTree(this.getResponseModels()));
            }
            if (this.getResponseParameters() != null) {
                obj.set("responseParameters", om.valueToTree(this.getResponseParameters()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnRouteResponseV2Props.Jsii$Proxy that = (CfnRouteResponseV2Props.Jsii$Proxy) o;

            if (!apiId.equals(that.apiId)) return false;
            if (!routeId.equals(that.routeId)) return false;
            if (!routeResponseKey.equals(that.routeResponseKey)) return false;
            if (this.modelSelectionExpression != null ? !this.modelSelectionExpression.equals(that.modelSelectionExpression) : that.modelSelectionExpression != null) return false;
            if (this.responseModels != null ? !this.responseModels.equals(that.responseModels) : that.responseModels != null) return false;
            return this.responseParameters != null ? this.responseParameters.equals(that.responseParameters) : that.responseParameters == null;
        }

        @Override
        public int hashCode() {
            int result = this.apiId.hashCode();
            result = 31 * result + (this.routeId.hashCode());
            result = 31 * result + (this.routeResponseKey.hashCode());
            result = 31 * result + (this.modelSelectionExpression != null ? this.modelSelectionExpression.hashCode() : 0);
            result = 31 * result + (this.responseModels != null ? this.responseModels.hashCode() : 0);
            result = 31 * result + (this.responseParameters != null ? this.responseParameters.hashCode() : 0);
            return result;
        }
    }
}

==> apigateway-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/CfnRouteResponseV2Props.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Properties for defining a `AWS::ApiGatewayV2::RouteResponse`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:51.583Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.CfnRouteResponseV2Props")
@software.amazon.jsii.Jsii.Proxy(CfnRouteResponseV2Props.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnRouteResponseV2Props extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ApiGatewayV2::RouteResponse.ApiId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html#cfn-apigatewayv2-routeresponse-apiid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getApiId();

    /**
     * `AWS::ApiGatewayV2::RouteResponse.RouteId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html#cfn-apigatewayv2-routeresponse-routeid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getRouteId();

    /**
     * `AWS::ApiGatewayV2::RouteResponse.RouteResponseKey`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html#cfn-apigatewayv2-routeresponse-routeresponsekey
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getRouteResponseKey();

    /**
     * `AWS::ApiGatewayV2::RouteResponse.ModelSelectionExpression`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html#cfn-apigatewayv2-routeresponse-modelselectionexpression
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.String getModelSelectionExpression() {
        return null;
    }

    /**
     * `AWS::ApiGatewayV2::RouteResponse.ResponseModels`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html#cfn-apigatewayv2-routeresponse-responsemodels
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.Object getResponseModels() {
        return null;
    }

    /**
     * `AWS::ApiGatewayV2::RouteResponse.ResponseParameters`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-routeresponse.html#cfn-apigatewayv2-routeresponse-responseparameters
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.Object getResponseParameters() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnRouteResponseV2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnRouteResponseV2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.String apiId;
        private java.lang.String routeId;
        private java.lang.String routeResponseKey;
        private java.lang.String modelSelectionExpression;
        private java.lang.Object responseModels;
        private java.lang.Object responseParameters;

        /**
         * Sets the value of ApiId
         * @param apiId `AWS::ApiGatewayV2::RouteResponse.ApiId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder apiId(java.lang.String apiId) {
            this.apiId = apiId;
            return this;
        }

        /**
         * Sets the value of RouteId
         * @param routeId `AWS::ApiGatewayV2::RouteResponse.RouteId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder routeId(java.lang.String routeId) {
            this.routeId = routeId;
            return this;
        }

        /**
         * Sets the value of RouteResponseKey
         * @param routeResponseKey `AWS::ApiGatewayV2::RouteResponse.RouteResponseKey`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder routeResponseKey(java.lang.String routeResponseKey) {
            this.routeResponseKey = routeResponseKey;
            return this;
        }

        /**
         * Sets the value of ModelSelectionExpression
         * @param modelSelectionExpression `AWS::ApiGatewayV2::RouteResponse.ModelSelectionExpression`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder modelSelectionExpression(java.lang.String modelSelectionExpression) {
            this.modelSelectionExpression = modelSelectionExpression;
            return this;
        }

        /**
         * Sets the value of ResponseModels
         * @param responseModels `AWS::ApiGatewayV2::RouteResponse.ResponseModels`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder responseModels(java.lang.Object responseModels) {
            this.responseModels = responseModels;
            return this;
        }

        /**
         * Sets the value of ResponseParameters
         * @param responseParameters `AWS::ApiGatewayV2::RouteResponse.ResponseParameters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder responseParameters(java.lang.Object responseParameters) {
            this.responseParameters = responseParameters;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnRouteResponseV2Props}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnRouteResponseV2Props build() {
            return new Jsii$Proxy(apiId, routeId, routeResponseKey, modelSelectionExpression, responseModels, responseParameters);
        }
    }

    /**
     * An implementation for {@link CfnRouteResponseV2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnRouteResponseV2Props {
        private final java.lang.String apiId;
        private final java.lang.String routeId;
        private final java.lang.String routeResponseKey;
        private final java.lang.String modelSelectionExpression;
        private final java.lang.Object responseModels;
        private final java.lang.Object responseParameters;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.apiId = this.jsiiGet("apiId", java.lang.String.class);
            this.routeId = this.jsiiGet("routeId", java.lang.String.class);
            this.routeResponseKey = this.jsiiGet("routeResponseKey", java.lang.String.class);
            this.modelSelectionExpression = this.jsiiGet("modelSelectionExpression", java.lang.String.class);
            this.responseModels = this.jsiiGet("responseModels", java.lang.Object.class);
            this.responseParameters = this.jsiiGet("responseParameters", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String apiId, final java.lang.String routeId, final java.lang.String routeResponseKey, final java.lang.String modelSelectionExpression, final java.lang.Object responseModels, final java.lang.Object responseParameters) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.apiId = java.util.Objects.requireNonNull(apiId, "apiId is required");
            this.routeId = java.util.Objects.requireNonNull(routeId, "routeId is required");
            this.routeResponseKey = java.util.Objects.requireNonNull(routeResponseKey, "routeResponseKey is required");
            this.modelSelectionExpression = modelSelectionExpression;
            this.responseModels = responseModels;
            this.responseParameters = responseParameters;
        }

        @Override
        public java.lang.String getApiId() {
            return this.apiId;
        }

        @Override
        public java.lang.String getRouteId() {
            return this.routeId;
        }

        @Override
        public java.lang.String getRouteResponseKey() {
            return this.routeResponseKey;
        }

        @Override
        public java.lang.String getModelSelectionExpression() {
            return this.modelSelectionExpression;
        }

        @Override
        public java.lang.Object getResponseModels() {
            return this.responseModels;
        }

        @Override
        public java.lang.Object getResponseParameters() {
            return this.responseParameters;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("apiId", om.valueToTree(this.getApiId()));
            data.set("routeId", om.valueToTree(this.getRouteId()));
            data.set("routeResponseKey", om.valueToTree(this.getRouteResponseKey()));
            if (this.getModelSelectionExpression() != null) {
                data.set("modelSelectionExpression", om.valueToTree(this.getModelSelectionExpression()));
            }
            if (this.getResponseModels() != null) {
                data.set("responseModels", om.valueToTree(this.getResponseModels()));
            }
            if (this.getResponseParameters() != null) {
                data.set("responseParameters", om.valueToTree(this.getResponseParameters()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-apigateway.CfnRouteResponseV2Props"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnRouteResponseV2Props.Jsii$Proxy that = (CfnRouteResponseV2Props.Jsii$Proxy) o;

            if (!apiId.equals(that.apiId)) return false;
            if (!routeId.equals(that.routeId)) return false;
            if (!routeResponseKey.equals(that.routeResponseKey)) return false;
            if (this.modelSelectionExpression != null ? !this.modelSelectionExpression.equals(that.modelSelectionExpression) : that.modelSelectionExpression != null) return false;
            if (this.responseModels != null ? !this.responseModels.equals(that.responseModels) : that.responseModels != null) return false;
            return this.responseParameters != null ? this.responseParameters.equals(that.responseParameters) : that.responseParameters == null;
        }

        @Override
        public int hashCode() {
            int result = this.apiId.hashCode();
            result = 31 * result + (this.routeId.hashCode());
            result = 31 * result + (this.routeResponseKey.hashCode());
            result = 31 * result + (this.modelSelectionExpression != null ? this.modelSelectionExpression.hashCode() : 0);
            result = 31 * result + (this.responseModels != null ? this.responseModels.hashCode() : 0);
            result = 31 * result + (this.responseParameters != null ? this.responseParameters.hashCode() : 0);
            return result;
        }
    }
}
